@@ -1,9 +1,9 @@
 package Role::Tiny::With;
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
-our $VERSION = '1.003004';
+our $VERSION = '2.000000';
 $VERSION = eval $VERSION;
 
 use Role::Tiny ();
